@@ -288,7 +288,7 @@ class Game(object):
 
         if split_text == ('list', 'units') or split_text == ('lu',):
             case = list_units
-        elif split_text[0] in ('unit', 'u') and len(split_text)==2:
+        elif len(split_text)==2 and split_text[0] in ('unit', 'u'):
             case = unit_info
         else:
             return None
@@ -572,6 +572,12 @@ class Game(object):
     def _execute_action_for(self, unit):
         action_type = type(unit.action)
 
+        def build_unit():
+            new_unit = self.new_unit(unit.player,
+                                 unit.action.destination,
+                                 unit.action.unit_type)
+            self.set_program(new_unit, unit.program)
+
         switch = {
             actions.StopAction : \
                 lambda: None,
@@ -587,9 +593,8 @@ class Game(object):
             actions.FireAction : \
                 lambda: self.fire_at(unit.action.destination),
             actions.BuildAction : \
-                lambda: self.new_unit(unit.player,
-                                      unit.action.destination,
-                                      unit.action.unit_type)}
+                build_unit
+        }
 
         case = switch[action_type]
         case()
